@@ -23,12 +23,11 @@ import org.apache.myfaces.tobago.ajax.AjaxUtils;
 import org.apache.myfaces.tobago.application.ProjectStage;
 import org.apache.myfaces.tobago.config.TobagoConfig;
 import org.apache.myfaces.tobago.context.Capability;
+import org.apache.myfaces.tobago.context.ClientProperties;
 import org.apache.myfaces.tobago.internal.webapp.DebugResponseWriterWrapper;
 import org.apache.myfaces.tobago.internal.webapp.HtmlResponseWriter;
 import org.apache.myfaces.tobago.internal.webapp.JsonResponseWriter;
 import org.apache.myfaces.tobago.internal.webapp.XmlResponseWriter;
-import org.apache.myfaces.tobago.util.FacesVersion;
-import org.apache.myfaces.tobago.util.VariableResolverUtils;
 import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -52,8 +51,6 @@ public class TobagoRenderKit extends RenderKit {
 
   public static final String RENDER_KIT_ID = "tobago";
 
-  private ResponseStateManager responseStateManager = new TobagoResponseStateManager();
-
   private RenderKit htmlBasicRenderKit;
 
   private Map<Key, Renderer> renderers = new HashMap<Key, Renderer>();
@@ -65,10 +62,10 @@ public class TobagoRenderKit extends RenderKit {
   }
 
   @Override
-  public Renderer getRenderer(String family, String rendererType) {
+  public Renderer getRenderer(final String family, final String rendererType) {
     Renderer renderer = renderers.get(new Key(family, rendererType));
     if (renderer == null) {
-      RenderKit renderKit = getHtmlBasicRenderKit();
+      final RenderKit renderKit = getHtmlBasicRenderKit();
       renderer = renderKit.getRenderer(family, rendererType);
       if (renderer != null) {
         renderer = new RendererBaseWrapper(renderer);
@@ -85,7 +82,7 @@ public class TobagoRenderKit extends RenderKit {
 
   private RenderKit getHtmlBasicRenderKit() {
     if (htmlBasicRenderKit == null) {
-      RenderKitFactory rkFactory = (RenderKitFactory) FactoryFinder.getFactory(FactoryFinder.RENDER_KIT_FACTORY);
+      final RenderKitFactory rkFactory = (RenderKitFactory) FactoryFinder.getFactory(FactoryFinder.RENDER_KIT_FACTORY);
       htmlBasicRenderKit =
           rkFactory.getRenderKit(FacesContext.getCurrentInstance(), RenderKitFactory.HTML_BASIC_RENDER_KIT);
     }
@@ -94,9 +91,9 @@ public class TobagoRenderKit extends RenderKit {
 
   @Override
   public ResponseWriter createResponseWriter(
-      Writer writer, String contentTypeList, String characterEncoding) {
+      final Writer writer, final String contentTypeList, final String characterEncoding) {
     String contentType;
-    FacesContext facesContext = FacesContext.getCurrentInstance();
+    final FacesContext facesContext = FacesContext.getCurrentInstance();
     if (AjaxUtils.isAjaxRequest(facesContext)) {
       return new JsonResponseWriter(writer, "application/json", characterEncoding);
     }
@@ -127,7 +124,7 @@ public class TobagoRenderKit extends RenderKit {
     }
 
     // content type xhtml is not supported in every browser... e. g. IE 6, 7, 8
-    if (!VariableResolverUtils.resolveClientProperties(FacesContext.getCurrentInstance())
+    if (!ClientProperties.getInstance(FacesContext.getCurrentInstance())
         .getUserAgent().hasCapability(Capability.CONTENT_TYPE_XHTML)) {
       contentType = "text/html";
     }
@@ -145,22 +142,17 @@ public class TobagoRenderKit extends RenderKit {
   }
 
   @Override
-  public void addRenderer(String family, String rendererType, Renderer renderer) {
+  public void addRenderer(final String family, final String rendererType, final Renderer renderer) {
     renderers.put(new Key(family, rendererType), renderer);
   }
 
   @Override
   public ResponseStateManager getResponseStateManager() {
-    if (FacesVersion.supports12() && FacesVersion.isMyfaces()
-        || FacesVersion.supports20() && FacesVersion.isMojarra()) {
-      return getHtmlBasicRenderKit().getResponseStateManager();
-    } else {
-      return responseStateManager;
-    }
+    return getHtmlBasicRenderKit().getResponseStateManager();
   }
 
   @Override
-  public ResponseStream createResponseStream(OutputStream outputStream) {
+  public ResponseStream createResponseStream(final OutputStream outputStream) {
     return getHtmlBasicRenderKit().createResponseStream(outputStream);
   }
 
@@ -168,12 +160,12 @@ public class TobagoRenderKit extends RenderKit {
     private final String family;
     private final String rendererType;
 
-    private Key(String family, String rendererType) {
+    private Key(final String family, final String rendererType) {
       this.family = family;
       this.rendererType = rendererType;
     }
 
-    public boolean equals(Object o) {
+    public boolean equals(final Object o) {
       if (this == o) {
         return true;
       }
@@ -181,7 +173,7 @@ public class TobagoRenderKit extends RenderKit {
         return false;
       }
 
-      Key key = (Key) o;
+      final Key key = (Key) o;
 
       if (!family.equals(key.family)) {
         return false;
